import argparse
import requests
from hindsight.behave import JiraConnector

def main():
    parser = argparse.ArgumentParser(description='Wrapper for BehaveForJira class to download features from the command line')
    parser.add_argument('host', help='Host URI for Jira installation')
    parser.add_argument('key', help='Project key to download features from')
    parser.add_argument('-u', '--username', help='User with Behave rights on project')
    parser.add_argument('-p', '--password', help='Password for User')
    parser.add_argument('-d', '--directory', help='Directory to download features to (default ./)')
    parser.add_argument('-m', '--manual', help='Include manual tagged scenarios in download', action='store_true')
    args = parser.parse_args()

    if not args.directory:
        dir = './'
    else:
        dir = args.directory

    if not args.username:
        username = None
        password = None
    else:
        username = args.username
        if not args.password:
            password = None
        else:
            password = args.password

    conn = JiraConnector()
    try:
        conn.fetch(host=args.host,key=args.key,username=username,password=password,manual=args.manual,dir=dir)
    except (requests.HTTPError, requests.ConnectionError, requests.RequestException) as e:
        print str(e)


import sys
import urllib
import urllib2
import base64
from zipfile import ZipFile

class JiraConnector:

    def fetch(self, host, key, username=None, password=None, dir='./', manual=1):
        if not host.endswith('/'):
            host += '/'

        path = host+'rest/cucumber/1.0/project/'+key+'/features?'+urllib.urlencode({'manual':bool(manual)})
        print 'Fetching from: ' + path

        req = urllib2.Request(path)
        req.add_header('Accept', 'application/zip')
        if username:
            prep = '%s:%s' % (username, password)
            base64string = base64.standard_b64encode(prep.encode('ascii'))
            encoded = 'Basic %s' % base64string.decode('ascii')
            req.add_header('Authorization', encoded)
        try:
            res = urllib2.urlopen(req)
        except urllib2.HTTPError, e:
            raise Exception('HTTPError (' + str(e.code) + '): ' + e.reason)
        except urllib2.URLError, e:
            raise Exception('URLError: ' + e.reason)
        else:
            print 'Fetched.'
            print 'Preparing to extract...'
            if sys.version[0] < '3':
                from StringIO import StringIO
                zip = ZipFile(StringIO(res.read()))
            else:
                from io import BytesIO
                zip = ZipFile(BytesIO(res.read()))
            infolist = zip.infolist()
            zip.extractall(path=dir)
            print 'Extracted ' + str(infolist.__len__()) + ' feature files into "' + dir + '"'





from setuptools import setup

setup(
    name='hindsight',
    version='0.1.5',
    packages=['hindsight'],
    description='Python tools for Hindsight Software',
    author='Jack Bastow',
    author_email='jack.bastow@hindsightsoftware.co.uk',
    url='http://pypi.python.org/pypi/hindsight/',
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read(),
    entry_points={
        'console_scripts': [
            'behave-cli = hindsight.cli:main'
        ]
    },
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development"
    ],
    use_2to3=True
)